<?php

namespace Drupal\recaptcha_preloader\Service;

use Drupal\Core\Asset\AssetResolverInterface;
use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Extension\ModuleHandlerInterface;
use Drupal\Core\Language\LanguageManagerInterface;
use Drupal\Core\Render\RendererInterface;

/**
 * Defines the helper service interface.
 */
interface RecaptchaPreloaderHelperInterface {

  /**
   * RecaptchaPreloaderHelper constructor.
   *
   * @param \Drupal\Core\Extension\ModuleHandlerInterface $module_handler
   *   The module handler.
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   The configuration factory.
   * @param \Drupal\Core\Asset\AssetResolverInterface $asset_resolver
   *   The asset resolver.
   * @param \Drupal\Core\Language\LanguageManagerInterface $language_manager
   *   The language manager.
   * @param \Drupal\Core\Render\RendererInterface $renderer
   *   The renderer.
   */
  public function __construct(
    ModuleHandlerInterface $module_handler,
    ConfigFactoryInterface $config_factory,
    AssetResolverInterface $asset_resolver,
    LanguageManagerInterface $language_manager,
    RendererInterface $renderer
  );

  /**
   * Disable submit form elements.
   *
   * @param array $elements
   *   The element array.
   */
  public function search(array &$elements);

  /**
   * Check if required settings are set to values for using preloader.
   *
   * @return bool
   *   TRUE if settings are set as needed.
   */
  public function isAvailable();

  /**
   * Generate a challenge.
   *
   * @return array
   *   The challenge.
   */
  public function build();

}
